sqlobject.tests.test_aggregates module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_aggregates module

class `sqlobject.tests.test_aggregates.` `FloatAccumulator`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = float_accumulator
  `q` = float_accumulator
  property `so_value`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_aggregates.FloatAccumulator`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'float_accumulator'

class `sqlobject.tests.test_aggregates.` `IntAccumulator`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = int_accumulator
  `q` = int_accumulator
  property `so_value`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_aggregates.IntAccumulator`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'int_accumulator'

`sqlobject.tests.test_aggregates.` `floatcmp`(f1, f2)

`sqlobject.tests.test_aggregates.` `test_float`()

`sqlobject.tests.test_aggregates.` `test_integer`()

`sqlobject.tests.test_aggregates.` `test_many`()